pub type AgentResponseAny = HttpResponse<Token, HttpRequestStreamingCallbackAny>;Aliased Type
pub struct AgentResponseAny {
pub status_code: u16,
pub headers: Vec<HeaderField<'static>>,
pub body: Vec<u8>,
pub streaming_strategy: Option<StreamingStrategy<Token, HttpRequestStreamingCallbackAny>>,
pub upgrade: Option<bool>,
}Fields
status_code: u16The HTTP status code.
headers: Vec<HeaderField<'static>>The response header map.
body: Vec<u8>The response body.
streaming_strategy: Option<StreamingStrategy<Token, HttpRequestStreamingCallbackAny>>The strategy for streaming the rest of the data, if the full response is to be streamed.
upgrade: Option<bool>Whether the query call should be upgraded to an update call.